package WebGUI::i18n::German::Asset_Matrix;
use utf8;
our $I18N = {
  'CATEGORY_NAME_loop' => {
    'lastUpdated' => '1202812528',
    'message' => 'Ein &quot;loop&quot; wird für jede Kategorie in dieser Matrix erstellt. Der Name des loops ergibt sich aus dem Namen der Kategorie, wobei alle Leerzeichen in Bindestriche umgewandelt und ein &quot;_loop&quot; am Ende angehängt wird. Wenn Sie also eine Kategorie namens &quot;Bells and Whistles&quot; haben, wird der loop dazu &quot;bells-and-whistles_loop&quot; heißen.'
  },
  'Return to Matrix' => {
    'lastUpdated' => '1250870457',
    'message' => 'Zurück zur Matrix'
  },
  'Sort by clicks' => {
    'lastUpdated' => '1251039636',
    'message' => 'nach Klicks'
  },
  'Sort by compares' => {
    'lastUpdated' => '1251039648',
    'message' => 'nach Vergleichen'
  },
  'Sort by name' => {
    'lastUpdated' => '1251039676',
    'message' => 'nach Name'
  },
  'Sort by updated' => {
    'lastUpdated' => '1251039657',
    'message' => 'nach Aktualität'
  },
  'Sort by views' => {
    'lastUpdated' => '1251039667',
    'message' => 'nach Aufrufen'
  },
  'add attribute label' => {
    'lastUpdated' => '1245433009',
    'message' => 'Attribut hinzufügen'
  },
  'add new listing label' => {
    'lastUpdated' => '1245433049',
    'message' => 'Klicken Sie hier, um eine neue Liste hinzuzufügen.'
  },
  'add new listing text' => {
    'lastUpdated' => '1245447514',
    'message' => 'Bitte berücksichtigen Sie, dass Sie bei Aufnahme einer neuen Liste verantwortlich sind für die Aktualität dieser Liste.'
  },
  'addMatrixListing_url' => {
    'lastUpdated' => '1245447551',
    'message' => 'URL zur Seite, wo ein Benutzer eine neue Liste zur Matrix hinzufügen kann.'
  },
  'approve or deny label' => {
    'lastUpdated' => '1250871105',
    'message' => 'Annehmen/Ablehnen'
  },
  'approve.url' => {
    'lastUpdated' => '1221289322',
    'message' => 'Die URL zum Überprüfen dieser Liste'
  },
  'assetName' => {
    'lastUpdated' => '1248911055',
    'message' => 'Matrix'
  },
  'attribute defaultValue description' => {
    'lastUpdated' => '1245447631',
    'message' => 'Geben Sie einen Standardwert für das Attribut ein, für den Fall dass es sich um eine Selectbox handelt.'
  },
  'attribute defaultValue label' => {
    'lastUpdated' => '1245448791',
    'message' => 'Standardwert'
  },
  'attribute description description' => {
    'lastUpdated' => '1250871434',
    'message' => 'Bitte beschreiben Sie dieses Attribut.'
  },
  'attribute description label' => {
    'lastUpdated' => '1245621157',
    'message' => 'Beschreibung'
  },
  'attribute name description' => {
    'lastUpdated' => '1250871527',
    'message' => 'Name des Attributs, das Sie erstellen möchten. Der Name muss eindeutig sein. Sie sollten dabei Groß-/Kleinschreibung beachten.'
  },
  'attribute name label' => {
    'lastUpdated' => '1245621132',
    'message' => 'Name'
  },
  'attribute options description' => {
    'lastUpdated' => '1250871618',
    'message' => 'Eingabe von Optionen (1 pro Zeile) für das Attribut für den Fall, dass es sich um eine Selektbox handelt.'
  },
  'attribute options label' => {
    'lastUpdated' => '1245620992',
    'message' => 'Optionen'
  },
  'attribute_loop' => {
    'lastUpdated' => '1250871802',
    'message' => 'Eine Schleife mit allen Attributen einer Kategorie von dieser Matrix.'
  },
  'best rated label' => {
    'lastUpdated' => '1245447656',
    'message' => 'Beste Bewertung'
  },
  'best.clicks.count' => {
    'lastUpdated' => '1202816280',
    'message' => 'Die Anzahl der Klicks des Listings, das die meisten Klicks hat.'
  },
  'best.clicks.name' => {
    'lastUpdated' => '1202816257',
    'message' => 'Der Name des Listings, das die meisten Klicks hat.'
  },
  'best.clicks.url' => {
    'lastUpdated' => '1202816315',
    'message' => 'Die URL des Listings, das die meisten Klicks hat.'
  },
  'best.compares.count' => {
    'lastUpdated' => '1202816359',
    'message' => 'Die Anzahl der Vergleiche des Listings, das die meisten Vergleiche hat.'
  },
  'best.compares.name' => {
    'lastUpdated' => '1202816392',
    'message' => 'Der Name des Listings, das die meisten Vergleiche hat.'
  },
  'best.compares.url' => {
    'lastUpdated' => '1202816436',
    'message' => 'Die URL des Listings, das die meisten Vergleiche hat.'
  },
  'best.posts.url' => {
    'lastUpdated' => '1202816469',
    'message' => 'Die URL des Listings, das die meisten Foreneinträge hat.'
  },
  'best.updated.date' => {
    'lastUpdated' => '1202816569',
    'message' => 'Das Datum des aktuellsten Listings.'
  },
  'best.updated.name' => {
    'lastUpdated' => '1222248464',
    'message' => 'Name der aktuellste Liste'
  },
  'best.updated.url' => {
    'lastUpdated' => '1222248481',
    'message' => 'URL der aktuellsten Liste'
  },
  'best.views.count' => {
    'lastUpdated' => '1222248762',
    'message' => 'Anzahl der Anzeigen der Liste mit höchster Klick-Anzahl'
  },
  'best.views.name' => {
    'lastUpdated' => '1222248635',
    'message' => 'Liste mit höchster Anzeigenanzahl'
  },
  'best.views.url' => {
    'lastUpdated' => '1221332796',
    'message' => 'Am meisten angeschaute URL'
  },
  'bestClicks_count' => {
    'lastUpdated' => '1245447709',
    'message' => 'Anzahl der Klicks auf die Liste mit den meisten Klicks.'
  },
  'bestClicks_name' => {
    'lastUpdated' => '1245447733',
    'message' => 'Name der Liste mit den meisten Klicks.'
  },
  'bestClicks_url' => {
    'lastUpdated' => '1245447753',
    'message' => 'URL zur Liste mit den meisten Klicks.'
  },
  'bestCompares_count' => {
    'lastUpdated' => '1245447846',
    'message' => 'Anzahl der Vergleiche mit der Liste mit den meisten Vergleichen.'
  },
  'bestCompares_name' => {
    'lastUpdated' => '1250872109',
    'message' => 'Name der Liste mit den meisten Vergleichen.'
  },
  'bestCompares_url' => {
    'lastUpdated' => '1245447877',
    'message' => 'URL zur Liste mit den meisten Vergleichen.'
  },
  'bestViews_count' => {
    'lastUpdated' => '1245447946',
    'message' => 'Anzahl der Betrachtungen der Liste mit den meisten Betrachtungen.'
  },
  'bestViews_name' => {
    'lastUpdated' => '1245621101',
    'message' => 'Name der Liste, die am meisten angeschaut wurde.'
  },
  'bestViews_url' => {
    'lastUpdated' => '1245448773',
    'message' => 'URL zur Liste mit den meisten Betrachtungen.'
  },
  'best_rating_loop' => {
    'lastUpdated' => '1250872433',
    'message' => 'Eine Schleife mit den besten Listenbewertungen für jede Kategorie dieser Matrix.'
  },
  'categories' => {
    'lastUpdated' => '1221288389',
    'message' => 'Kategorien'
  },
  'categories default value' => {
    'lastUpdated' => '1245621041',
    'message' => 'Vorteile'
  },
  'categories description' => {
    'lastUpdated' => '1250872771',
    'message' => 'Geben Sie hier eine Kategorie pro Zeile an um die Kategorien für diese Matrix zu definieren. Kategorien werden benutzt um Attribute zu gruppieren. Benutzer können Kategorien in einer Liste bewerten.'
  },
  'categories label' => {
    'lastUpdated' => '1245448731',
    'message' => 'Kategorien'
  },
  'categories subtext' => {
    'lastUpdated' => '1250872883',
    'message' => 'Geben Sie eine Kategorie pro Zeile in der gewünschten Reihenfolge ein. Achten Sie darauf keine Leerzeichen am Anfang und am Ende zu verwenden.'
  },
  'category' => {
    'lastUpdated' => '1221333000',
    'message' => 'Kategorie'
  },
  'category description' => {
    'lastUpdated' => '1250873036',
    'message' => 'Wählen Sie eine Kategorie für dieses Attribut.'
  },
  'category label' => {
    'lastUpdated' => '1234944496',
    'message' => 'Kategorie'
  },
  'category listing description' => {
    'lastUpdated' => '1221334050',
    'message' => 'Beschreibung dieses Feldes aus Benutzersicht.'
  },
  'categoryLabel' => {
    'lastUpdated' => '1244363003',
    'message' => 'Kategorie'
  },
  'category_loop' => {
    'lastUpdated' => '1250873140',
    'message' => 'Eine Schleife mit allen Kategorien in dieser Matrix.'
  },
  'class' => {
    'lastUpdated' => '1222248717',
    'message' => 'Name der Stylesheet-Klasse für dieses Feld.'
  },
  'clicks' => {
    'lastUpdated' => '1222248663',
    'message' => 'Anzahl der Klicks für diese Liste'
  },
  'clicks label' => {
    'lastUpdated' => '1245448743',
    'message' => 'Klicks'
  },
  'columnCount' => {
    'lastUpdated' => '1223575738',
    'message' => 'Anzahl der Einträge im Vergleich'
  },
  'column_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'combo' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'comment' => {
    'lastUpdated' => '1202812266',
    'message' => 'Kommentar'
  },
  'compare button label' => {
    'lastUpdated' => '1244363153',
    'message' => 'Vergleichen'
  },
  'compare color costs extra description' => {
    'lastUpdated' => '1250873205',
    'message' => 'Selektieren Sie die Farbe für "Kostet extra" in der Vergleichsmatrix.'
  },
  'compare color costs extra label' => {
    'lastUpdated' => '1250873246',
    'message' => 'Vergleichsfarbe: Kostet extra'
  },
  'compare color free add on description' => {
    'lastUpdated' => '1250873295',
    'message' => 'Selektieren Sie die Farbe für "Kostenlose Erweiterung" in der Vergleichsmatrix.'
  },
  'compare color free add on label' => {
    'lastUpdated' => '1250873382',
    'message' => 'Vergleichsfarbe: Kostenlose Erweiterung'
  },
  'compare color limited description' => {
    'lastUpdated' => '1250873526',
    'message' => 'Selektieren Sie die Farbe für "Limitiert" in der Vergleichsmatrix.'
  },
  'compare color limited label' => {
    'lastUpdated' => '1250873589',
    'message' => 'Vergleichsfarbe: Limitiert'
  },
  'compare color no description' => {
    'lastUpdated' => '1250873574',
    'message' => 'Selektieren Sie die Farbe für "Nein" in der Vergleichsmatrix.'
  },
  'compare color no label' => {
    'lastUpdated' => '1250873607',
    'message' => 'Vergleichsfarbe: Nein'
  },
  'compare color yes description' => {
    'lastUpdated' => '1250873627',
    'message' => 'Selektieren Sie die Farbe für "Ja" in der Vergleichsmatrix.'
  },
  'compare color yes label' => {
    'lastUpdated' => '1250873641',
    'message' => 'Vergleichsfarbe: Ja'
  },
  'compare template' => {
    'lastUpdated' => '1222246986',
    'message' => 'Vorlage Vergleich'
  },
  'compare template description' => {
    'lastUpdated' => '1250873727',
    'message' => 'Selektiere eine Vorlage für die Anzeige im Listen-Vergleich.'
  },
  'compare template label' => {
    'lastUpdated' => '1247509084',
    'message' => 'Vergleichsvorlage'
  },
  'compare.form' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'compareForm' => {
    'lastUpdated' => '1250874880',
    'message' => 'Das Vergleichsformular. Die Liste der Matrixlisten in diesem Formular ist eine yui-Datentabelle. Siehe die yui-Dokumentation unter <a href="http://developer.yahoo.com/yui/examples/datatable/dt_skinning.html" target="new">yui docs</a> für Informationen über die Darstellung von yui-Datentabellen.'
  },
  'compares' => {
    'lastUpdated' => '1221289254',
    'message' => 'Anzahl der Vergleiche zu dieser Liste'
  },
  'compares label' => {
    'lastUpdated' => '1250874306',
    'message' => 'Vergleiche'
  },
  'comparison label' => {
    'lastUpdated' => '1244363136',
    'message' => 'Vergleich'
  },
  'comparison template help body' => {
    'lastUpdated' => '1247903788',
    'message' => 'Sowohl das Vergleichsformular als auch die Matrix-Vergleichsliste werden dynamisch mit yui-Datentabellen generiert. Siehe auch <a href="http://developer.yahoo.com/yui/examples/datatable/dt_skinning.html" target="new">yui docs</a> für die weitere Gestaltung der yui-Tabellen.'
  },
  'comparison template help title' => {
    'lastUpdated' => '1315294310',
    'message' => 'Matrix, Variablen Matrixvergleich Vorlage'
  },
  'count' => {
    'lastUpdated' => '1250875162',
    'message' => 'Summe aller Bewertungen der besten/schlechtesten Liste innerhalb dieser Kategorie.'
  },
  'create account label' => {
    'lastUpdated' => '1244362751',
    'message' => 'Benutzerkonto anlegen'
  },
  'create account part1 text' => {
    'lastUpdated' => '1250875287',
    'message' => 'Wenn Sie ein Produkt herstellen oder ein Experte sind, der die Liste dazu pflegen möchte,'
  },
  'create account part2 text' => {
    'lastUpdated' => '1250875336',
    'message' => 'dann können Sie Ihre Liste registrieren.'
  },
  'current.user.count' => {
    'lastUpdated' => '1221333148',
    'message' => 'Anzahl derzeitiger Besucher dieser Website.'
  },
  'default sort description' => {
    'lastUpdated' => '1250875446',
    'message' => 'Selektieren Sie die Standardsortierfolge für die Listen im Vergleichsfenster.'
  },
  'default sort label' => {
    'lastUpdated' => '1245621193',
    'message' => 'Standardsortierung'
  },
  'default value' => {
    'lastUpdated' => '1222248799',
    'message' => 'Standardwert'
  },
  'default value description' => {
    'lastUpdated' => '1222248905',
    'message' => 'Standardwert für das Feld, falls der Benutzer es nicht ausfüllt.'
  },
  'delete attribute confirm message' => {
    'lastUpdated' => '1250875519',
    'message' => 'Sind Sie sicher, dass Sie dieses Attribut und alle damit verbundenen Daten löschen möchten?'
  },
  'delete field confirm' => {
    'lastUpdated' => '1223568082',
    'message' => 'Möchten Sie dieses Feld und den abhängigen Daten wirklich l&ouml;schen?'
  },
  'delete listing confirmation' => {
    'lastUpdated' => '1249632986',
    'message' => 'Sind Sie wirklich sicher, dass Sie diese Liste löschen möchten?
Alle Daten gehen verloren und Sie können das nicht rückgängig machen!!<br><br><span></span><a href="http://i18n.webgui.org/%s">Nein, ich habe einen Fehler gemacht.</a><br><br><span></span><a href="http://i18n.webgui.org/%s">Ja!</a><br><br>'
  },
  'delete.url' => {
    'lastUpdated' => '1224970703',
    'message' => 'Die URL zum Löschen dieser Liste'
  },
  'description' => {
    'lastUpdated' => '1250876107',
    'message' => 'Eine detaillierte Attribut-Beschreibung die im Hover-Over-Tooltipp verwendet wird.'
  },
  'description description' => {
    'lastUpdated' => '1223568158',
    'message' => 'Allgemeine Beschreibung zum Produkt. Details können in den sonstigen Feldern beschriben werden. '
  },
  'detail count' => {
    'lastUpdated' => '1223575797',
    'message' => 'Total für diesen Eintrag'
  },
  'detail mean' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'detail median' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'detail template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'detail template description' => {
    'lastUpdated' => '1250876249',
    'message' => 'Wähle ein Template für die Darstellung der detaillierten Listeninformation.'
  },
  'detail template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'detail template label' => {
    'lastUpdated' => '1247510309',
    'message' => 'Detailvorlage'
  },
  'detail_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'details url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'discussion' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'edit attribute title' => {
    'lastUpdated' => '1244363096',
    'message' => 'Hinzufügen/Berabeiten Attribut'
  },
  'edit field' => {
    'lastUpdated' => '1223568231',
    'message' => 'Datenfeld editieren'
  },
  'edit listing' => {
    'lastUpdated' => '1244363120',
    'message' => 'Liste bearbeiten'
  },
  'edit listing template description' => {
    'lastUpdated' => '1250876466',
    'message' => 'Selektiere ein Template für die Listenbearbeitung.'
  },
  'edit listing template label' => {
    'lastUpdated' => '1248720139',
    'message' => 'Vorlage zur Listenbearbeitung'
  },
  'edit matrix' => {
    'lastUpdated' => '1244363078',
    'message' => 'Bearbeiten Matrix'
  },
  'edit.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'email.form' => {
    'lastUpdated' => '1222248991',
    'message' => 'Formular für Email an den Listenverantwortlichen'
  },
  'email.wasSent' => {
    'lastUpdated' => '1222250100',
    'message' => 'Email wurde verschickt.'
  },
  'expand the matrix label' => {
    'lastUpdated' => '1247903370',
    'message' => 'Matrix erweitern'
  },
  'export attributes label' => {
    'lastUpdated' => '1250876506',
    'message' => 'Exportieren Attribute'
  },
  'exportAttributes_url' => {
    'lastUpdated' => '1249633438',
    'message' => 'Die URL zum Export der Listenattribute zu dieser Matrix.'
  },
  'extra' => {
    'lastUpdated' => '1222249020',
    'message' => 'Kostet extra'
  },
  'field description' => {
    'lastUpdated' => '1223575836',
    'message' => 'Beschreibung Eigenschaft'
  },
  'field description description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field label' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field label description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field name' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field name description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field type' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field type description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'field.list.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'fieldType' => {
    'lastUpdated' => '1250876620',
    'message' => 'Feldtyp, der für dieses Matrix-Feld spezifiziert wird.'
  },
  'fieldType description' => {
    'lastUpdated' => '1250876914',
    'message' => 'Feldtyp für das Attribut das Sie erstellen. Bitte wählen Sie den Feldtyp aus den Optionen der Drop-Down-Liste.'
  },
  'fieldType label' => {
    'lastUpdated' => '1247509095',
    'message' => 'Feldtyp'
  },
  'form' => {
    'lastUpdated' => '1250930978',
    'message' => 'Formularelement für dieses Attribut.'
  },
  'form.footer' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'form.header' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'form.submit' => {
    'lastUpdated' => '1222247162',
    'message' => 'Der Knopf zum Abschicken'
  },
  'free' => {
    'lastUpdated' => '1222249178',
    'message' => 'Kostenlose Erweiterung'
  },
  'general comment' => {
    'lastUpdated' => '1221289192',
    'message' => 'Allgemeiner Kommentar'
  },
  'good bad' => {
    'lastUpdated' => '1223568258',
    'message' => 'Gut Schlecht'
  },
  'group to add' => {
    'lastUpdated' => '1244362773',
    'message' => 'Wer kann Listen hinzufügen?'
  },
  'group to add description' => {
    'lastUpdated' => '1248721110',
    'message' => 'Diese Gruppe kann Listen hinzufügen oder bearbeiten.'
  },
  'group to add label' => {
    'lastUpdated' => '1244362840',
    'message' => 'Gruppe zum Hinzufügen'
  },
  'hide stickied button label' => {
    'lastUpdated' => '1250931095',
    'message' => 'Markierte Einträge anzeigen / nicht anzeigen'
  },
  'id' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'isLoggedIn' => {
    'lastUpdated' => '1223575900',
    'message' => 'Angabe, ob der aktuelle Benutzer sich angemeldet hat.'
  },
  'isPending' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'isTooFew' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'isTooMany' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'javascript' => {
    'lastUpdated' => '1245448135',
    'message' => 'Inline Javascript für diese Vorlage.'
  },
  'label' => {
    'lastUpdated' => '1250931261',
    'message' => 'Beschriftung zum Attribut'
  },
  'last updated label' => {
    'lastUpdated' => '1244362857',
    'message' => 'Zuletzt aktualisiert'
  },
  'lastUpdated' => {
    'lastUpdated' => '1250931311',
    'message' => 'Datum letzter Aktualisierung dieser Liste'
  },
  'lastUpdated.date' => {
    'lastUpdated' => '1223575987',
    'message' => 'Datum letzter Aktualisierung dieser Liste'
  },
  'lastUpdated.epoch' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'last_update_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'last_updated_loop' => {
    'lastUpdated' => '1250931355',
    'message' => 'Eine Schleife mit den 20 aktuellsten Listen.'
  },
  'lastupdated_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'limited' => {
    'lastUpdated' => '1223568335',
    'message' => 'Eingeschränkt'
  },
  'list attributes label' => {
    'lastUpdated' => '1250931397',
    'message' => 'List-Attribute'
  },
  'list attributes title' => {
    'lastUpdated' => '1250931430',
    'message' => 'Attribut-Liste'
  },
  'list fields' => {
    'lastUpdated' => '1223568380',
    'message' => 'Liste der Eigenschaften'
  },
  'listAttributes_url' => {
    'lastUpdated' => '1250931520',
    'message' => 'Die URL zur Seite, wo Sie neue Listen-Attribute für diese Matrix definieren können.'
  },
  'listing count label' => {
    'lastUpdated' => '1247509119',
    'message' => 'Listenzähler'
  },
  'listing description' => {
    'lastUpdated' => '1221289117',
    'message' => 'Beschreibung dieser Liste'
  },
  'listing label' => {
    'lastUpdated' => '1223576010',
    'message' => 'Bezeichnung zu diesem Feld, welches den Inhalt repräsentiert.'
  },
  'listing maintainer' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'listing maintainer description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'listing name' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'listing statistics label' => {
    'lastUpdated' => '1250931618',
    'message' => 'Listenstatistiken'
  },
  'listing.add.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'listing.count' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'listingCount' => {
    'lastUpdated' => '1245432978',
    'message' => 'Anzahl der Listen dieser Matrix'
  },
  'listings cache timeout description' => {
    'lastUpdated' => '1250931810',
    'message' => 'Zur Optimierung der Zugriffszeiten, können die Matrixlisten gecached werden. Wie lange sollen die Listen im Cache verbleiben?'
  },
  'listings cache timeout label' => {
    'lastUpdated' => '1250931854',
    'message' => 'Listen-Cache-Timeout'
  },
  'main template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'main template description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manufacturer name' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manufacturer name description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manufacturer url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manufacturer url description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'manufacturerName' => {
    'lastUpdated' => '1222248325',
    'message' => 'Name des Herstellers oder Dienstleisters für das Produkt dieser Liste'
  },
  'manufacturerUrl' => {
    'lastUpdated' => '1222248353',
    'message' => 'URL des Herstellers'
  },
  'manufacturerUrl.click' => {
    'lastUpdated' => '1222250378',
    'message' => 'Hersteller/Dienstleister URL, wenn Sie die Anzahl der Clicks zu dieser Liste registrieren möchten'
  },
  'matrix asset template variables title' => {
    'lastUpdated' => '1250931979',
    'message' => 'Matrix-Asset-Vorlagen-Variablen'
  },
  'matrix fieldtype' => {
    'lastUpdated' => '1250931995',
    'message' => 'Matrix-Feldtyp'
  },
  'matrix specific fields' => {
    'lastUpdated' => '1223576037',
    'message' => 'Matrix-spezifische Felder'
  },
  'matrix specific fields description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'matrix template help title' => {
    'lastUpdated' => '1315294409',
    'message' => 'Matrix, Variablen der Matrix-Hauptvorlage'
  },
  'max comparisons' => {
    'lastUpdated' => '1221289007',
    'message' => 'Matrix Vergleiche'
  },
  'max comparisons description' => {
    'lastUpdated' => '1221289066',
    'message' => 'Gibt an, wie viele Vergleiche beim Suchen und Vergleichen erlaubt sind.'
  },
  'max comparisons label' => {
    'lastUpdated' => '1247904422',
    'message' => 'Max. Vergleiche'
  },
  'max comparisons privileged' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'max comparisons privileged description' => {
    'lastUpdated' => '1250932275',
    'message' => 'Legt die Anzahl der Vergleiche für Suche und Vergleich fest, die ein registrierter Benutzer verwenden kann.'
  },
  'max comparisons privileged label' => {
    'lastUpdated' => '1250932329',
    'message' => 'Max. Vergleiche für registrierte Benutzer'
  },
  'max screenshot height description' => {
    'lastUpdated' => '1250932438',
    'message' => 'Selektieren Sie die maximale Höhe der Screenshots in dieser Matrix. Größere Screenshots werden entsprechend verkleinert.'
  },
  'max screenshot height label' => {
    'lastUpdated' => '1250932482',
    'message' => 'Maximale Screenshot-Höhe '
  },
  'max screenshot width description' => {
    'lastUpdated' => '1250932555',
    'message' => 'Selektieren Sie die maximale Breite der Screenshots in dieser Matrix. Größere Screenshots werden entsprechend verkleinert.'
  },
  'max screenshot width label' => {
    'lastUpdated' => '1250932581',
    'message' => 'Maximale Screenshot-Breite'
  },
  'maxgroup description' => {
    'lastUpdated' => '1250932846',
    'message' => 'Selektieren Sie eine Gruppe, für die ein spezieller maximaler Vergleich ausgewählt werden kann. '
  },
  'maxgroup label' => {
    'lastUpdated' => '1250932891',
    'message' => 'Priviligierte Maximum-Gruppe'
  },
  'maxgroup per description' => {
    'lastUpdated' => '1250932981',
    'message' => 'Legt fest, wieviele Vergleiche von Mitgliedern der priviligierten Gruppe durchgeführt werden können.'
  },
  'maxgroup per label' => {
    'lastUpdated' => '1245621339',
    'message' => 'Maximum für priviligierte Gruppe.'
  },
  'mean' => {
    'lastUpdated' => '1245448244',
    'message' => 'Durchschnittsbewertung der besten/schlechtesten Liste in dieser Kategorie'
  },
  'median' => {
    'lastUpdated' => '1250933195',
    'message' => 'Der Mittelwert der besten/schlechtesten Liste in dieser Kategorie.'
  },
  'most clicks label' => {
    'lastUpdated' => '1247903939',
    'message' => 'Meiste Klicks'
  },
  'most compares label' => {
    'lastUpdated' => '1247903954',
    'message' => 'Meiste Vergleiche'
  },
  'most recently updated label' => {
    'lastUpdated' => '1247903969',
    'message' => 'Zuletzt aktualisiert'
  },
  'most views label' => {
    'lastUpdated' => '1245621307',
    'message' => 'Am meisten angeschaut'
  },
  'name' => {
    'lastUpdated' => '1250933437',
    'message' => 'Listenname'
  },
  'no' => {
    'lastUpdated' => '1192797177',
    'message' => 'Nein'
  },
  'no copy' => {
    'lastUpdated' => '1222247254',
    'message' => 'Dieses Asset darf nicht kopiert werden'
  },
  'no edit rights' => {
    'lastUpdated' => '1250933468',
    'message' => 'Sie haben keine Berechtigung, diese Liste zu ändern.'
  },
  'pending listings label' => {
    'lastUpdated' => '1247509277',
    'message' => 'Freizugebende Listen'
  },
  'pending_list' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'pending_loop' => {
    'lastUpdated' => '1247509249',
    'message' => 'Eine Schleife mit Listen die noch freigegeben werden sollten. '
  },
  'privileged group' => {
    'lastUpdated' => '1244362970',
    'message' => 'Wer soll priviligierte Rechte haben?'
  },
  'privileged group description' => {
    'lastUpdated' => '1250933733',
    'message' => 'Diese Gruppe hat besondere Rechte in Bezug auf die maximal erlaubte Anzahl von Vergleichen und die Frequenz womit bewertet werden kann. '
  },
  'product name' => {
    'lastUpdated' => '1222248244',
    'message' => 'Produktname'
  },
  'product name description' => {
    'lastUpdated' => '1250933868',
    'message' => 'Bitte geben Sie den Namen des Produktes an. Wenn es Einträge gibt mit verschiedenen Versionen des Produkts, ist es empfehlenswert, dass die Produktnamen gleich sind.'
  },
  'product url' => {
    'lastUpdated' => '1222247533',
    'message' => 'URL zum Produkt'
  },
  'product url description' => {
    'lastUpdated' => '1222247588',
    'message' => 'Wenn es eine eigene Website für das Produkt gibt, geben Sie hier die komplette URL ein'
  },
  'productName' => {
    'lastUpdated' => '1222247741',
    'message' => 'Name dieser Liste'
  },
  'productUrl' => {
    'lastUpdated' => '1222247770',
    'message' => 'Hersteller URL für diese Liste'
  },
  'productUrl.click' => {
    'lastUpdated' => '1222247846',
    'message' => 'Die Produkt-URL, falls die Klicks auf diese Liste gezählt werden sollen.'
  },
  'product_loop' => {
    'lastUpdated' => '1222247918',
    'message' => 'Eine Schleife mit der Produktinformation (nicht in Kategorien enthalten) für diese Liste.'
  },
  'rating detail template' => {
    'lastUpdated' => '1222247954',
    'message' => 'Vorlage zu Bewertungsdetails'
  },
  'rating detail template description' => {
    'lastUpdated' => '1250934018',
    'message' => 'Selektiere eine Vorlage zur Anzeige der Bewertungsdetails.'
  },
  'rating detail template label' => {
    'lastUpdated' => '1250934127',
    'message' => 'Bewertungsdetail-Vorlage'
  },
  'rating group' => {
    'lastUpdated' => '1245448541',
    'message' => 'Wer kann Listen bewerten?'
  },
  'rating group description' => {
    'lastUpdated' => '1250930656',
    'message' => 'Diese Gruppe hat die Berechtigung Listen zu bewerten.'
  },
  'rating timeout' => {
    'lastUpdated' => '1245448578',
    'message' => 'Erforderliche Zeit zwischen Bewertungen.'
  },
  'rating timeout description' => {
    'lastUpdated' => '1250934256',
    'message' => 'Stellt eine Zeit zwischen Bewertungen ein, damit Besucher eine Liste nicht zu oft bewerten können. '
  },
  'rating timeout privileged' => {
    'lastUpdated' => '1250934313',
    'message' => 'Mindestzeit zwischen Bewertungen für priviligierte Benutzer'
  },
  'rating timeout privileged description' => {
    'lastUpdated' => '1250934509',
    'message' => 'Priviligierte Benutzer können eine andere Zeit zwischen Bewertungen haben als normale Benutzer welche die Erlaubnis zur Bewertung haben. '
  },
  'rating_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'ratings' => {
    'lastUpdated' => '1222250413',
    'message' => 'Bewertungsformular für diese Liste'
  },
  'ratings detail template help title' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'ratings duration description' => {
    'lastUpdated' => '1250931021',
    'message' => 'Selektieren Sie die Zeit wonach alte Bewertungen gelöscht werden.'
  },
  'ratings duration label' => {
    'lastUpdated' => '1247904272',
    'message' => 'Bewertungsdauer'
  },
  'ratings.details.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'report error' => {
    'lastUpdated' => '1222248040',
    'message' => 'Fehler melden'
  },
  'request type' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'row_loop' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'screenshot' => {
    'lastUpdated' => '1222250170',
    'message' => 'Screenshot/Bild'
  },
  'screenshot help' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'screenshots config template description' => {
    'lastUpdated' => '1250930835',
    'message' => 'Selektieren Sie eine Vorlage für die Screenshot-Konfiguration einer Liste.'
  },
  'screenshots config template label' => {
    'lastUpdated' => '1250934673',
    'message' => 'Vorlage zur Listenscreenshot-Konfiguration'
  },
  'screenshots template description' => {
    'lastUpdated' => '1250934755',
    'message' => 'Selektieren Sie eine Vorlage für die Darstellung der Listen-Screenshots.'
  },
  'screenshots template label' => {
    'lastUpdated' => '1250934799',
    'message' => 'Listenscreenshots-Vorlage'
  },
  'search field description' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search label' => {
    'lastUpdated' => '1244362980',
    'message' => 'Suchen'
  },
  'search template' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'search template description' => {
    'lastUpdated' => '1247510506',
    'message' => 'Selektieren Sie eine Vorlage für den "Suchen"-Bildschirm.'
  },
  'search template help title' => {
    'lastUpdated' => '1315294483',
    'message' => 'Matrix, Variablen der Matrix-Suchvorlage'
  },
  'search template label' => {
    'lastUpdated' => '1245448652',
    'message' => 'Suchvorlage'
  },
  'search.url' => {
    'lastUpdated' => '1222250288',
    'message' => 'URL zum Suchformular'
  },
  'search_url' => {
    'lastUpdated' => '1250935007',
    'message' => 'URL zur Matrix-Suchseite'
  },
  'show ratings' => {
    'lastUpdated' => '1202812306',
    'message' => 'Bewertungen anzeigen'
  },
  'site statistics label' => {
    'lastUpdated' => '1250935023',
    'message' => 'Site-Statistik'
  },
  'sort alpha numeric label' => {
    'lastUpdated' => '1245621376',
    'message' => 'Alphanumerisch'
  },
  'sort by asset rank label' => {
    'lastUpdated' => '1250935118',
    'message' => 'Assetrang'
  },
  'sort by last updated label' => {
    'lastUpdated' => '1250935194',
    'message' => 'Letzte Aktualisierung'
  },
  'sort by score label' => {
    'lastUpdated' => '1250935274',
    'message' => 'Bewertung'
  },
  'statistics cache timeout description' => {
    'lastUpdated' => '1250935433',
    'message' => 'Weil alle Benutzer die Matrix-Statistiken in gleicher Form sehen, können diese zur Leistungssteigerung für eine gewisse Zeit zwischengespeichert werden. Wie lange sollten die Statistiken zwischengespeichert werden?'
  },
  'statistics cache timeout label' => {
    'lastUpdated' => '1250935486',
    'message' => 'Statistik-Cache-Timeout'
  },
  'submission approval workflow description' => {
    'lastUpdated' => '1250935523',
    'message' => 'Selektieren Sie den Workflow zur Listenfreigabe.'
  },
  'submission approval workflow label' => {
    'lastUpdated' => '1250935571',
    'message' => 'Workflow zur Listenfreigabe'
  },
  'template description' => {
    'lastUpdated' => '1250935607',
    'message' => 'Selektieren Sie eine Vorlage zur Standardanzeige der Matrix.'
  },
  'template label' => {
    'lastUpdated' => '1245448510',
    'message' => 'Matrixvorlage'
  },
  'text' => {
    'lastUpdated' => '1192797250',
    'message' => 'Text'
  },
  'text area' => {
    'lastUpdated' => '1192797270',
    'message' => 'Textbereich'
  },
  'thumbnail' => {
    'lastUpdated' => '1223568622',
    'message' => 'Die URL zum Thumbnail dieses Bildes'
  },
  'tmplVar best.category' => {
    'lastUpdated' => '1222248072',
    'message' => 'Name dieser Kategorie'
  },
  'tmplVar best.name' => {
    'lastUpdated' => '1221333426',
    'message' => 'Name der Liste mit bester Bewertung innerhalb dieser Kategorie'
  },
  'tmplVar best.url' => {
    'lastUpdated' => '1221333469',
    'message' => 'URL der Liste mit bester Bewertung innerhalb dieser Kategorie'
  },
  'tmplVar category' => {
    'lastUpdated' => '1221333501',
    'message' => 'Name der Kategorie für dieses Feld'
  },
  'tmplVar class' => {
    'lastUpdated' => '1221333630',
    'message' => 'Stylesheet-Klasse für dieses Feld. Die Klasse ist der Wert des Feldes, wobei Leerzeichen mit Unterstrich ersetzt werden. Sonstige nicht alpha-numerische Zeichen werden entfernt.'
  },
  'tmplVar detail url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar field.description' => {
    'lastUpdated' => '1222249324',
    'message' => 'Beschreibung'
  },
  'tmplVar last.lastUpdated' => {
    'lastUpdated' => '1222249270',
    'message' => 'Letzte Aktualisierung'
  },
  'tmplVar last.name' => {
    'lastUpdated' => '1222247343',
    'message' => 'Name des Produktes'
  },
  'tmplVar last.url' => {
    'lastUpdated' => '1222250218',
    'message' => 'URL zu dieser Liste'
  },
  'tmplVar name' => {
    'lastUpdated' => '1221333721',
    'message' => 'Name dieses Feldes'
  },
  'tmplVar pending.productName' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar pending.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar screenshot' => {
    'lastUpdated' => '1221333682',
    'message' => 'Die URL zur hochgeladenen Bild oder Screenshot.'
  },
  'tmplVar worst.category' => {
    'lastUpdated' => '1222248081',
    'message' => 'Name dieser Kategorie'
  },
  'tmplVar worst.count' => {
    'lastUpdated' => '1223576454',
    'message' => 'Summe der Bewertungen der Liste, die in dieser Kategorie am schlechtesten abschneidet.'
  },
  'tmplVar worst.mean' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar worst.median' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar worst.name' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'tmplVar worst.url' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'too few message' => {
    'lastUpdated' => '1260984447',
    'message' => 'Für einen Vergleich müssen mindestens zwei Einträge markiert sein. Wenn Sie nur einen Eintrag anschauen möchten, klicken Sie bitte auf deren Namen.'
  },
  'too many message' => {
    'lastUpdated' => '1260984527',
    'message' => 'Sie können maxmimal %d Einträge miteinander vergleichen. Bitter korrigieren Sie ihre Auswahl und starten das Vergleichen nochmals.'
  },
  'url' => {
    'lastUpdated' => '1250935843',
    'message' => 'Listen-URL'
  },
  'user.canApprove' => {
    'lastUpdated' => '1223576224',
    'message' => 'Bedingung, die angibt ob der angemeldete Benutzer diese Liste freigeben kann.'
  },
  'user.canEdit' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'user.count' => {
    'lastUpdated' => '1222247309',
    'message' => 'Anzahl der registrierten Benutzer'
  },
  'value' => {
    'lastUpdated' => '1192797371',
    'message' => 'Wert des Feldes'
  },
  'version' => {
    'lastUpdated' => '1221288008',
    'message' => 'Versions- oder Modellnummer des Produkts'
  },
  'version number' => {
    'lastUpdated' => '1221288074',
    'message' => 'Versions-/Modellnummer'
  },
  'version number description' => {
    'lastUpdated' => '1221288203',
    'message' => 'Versionsnummer'
  },
  'versionNumber' => {
    'lastUpdated' => '1221288245',
    'message' => 'Versions-/Modellnummer des Produkts'
  },
  'views' => {
    'lastUpdated' => '1222248194',
    'message' => 'Gesamtanzahl der Anzeigen zu dieser Liste'
  },
  'views label' => {
    'lastUpdated' => '1245448396',
    'message' => 'Betrachtungen'
  },
  'visitor cache timeout' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'visitor cache timeout help' => {
    'lastUpdated' => undef,
    'message' => ''
  },
  'worst rated label' => {
    'lastUpdated' => '1245448429',
    'message' => 'Am Schlechtesten bewertet'
  },
  'worst_rating_loop' => {
    'lastUpdated' => '1250936152',
    'message' => 'Eine Schleife mit den schlechtesten bewerteten Listen für jede Kategorie dieser Matrix.'
  },
  'yes' => {
    'lastUpdated' => '1192797163',
    'message' => 'Ja'
  },
  'your email' => {
    'lastUpdated' => '1202812354',
    'message' => 'E-Mail-Adresse'
  }
}
;

1;
